==> smenu-0_6_6.tgz: SMenu/skins/SMenu/makeMenu_ul.py <==
## Script (Python) "makeMenu_ul"
##bind container=container
##bind context=context
##bind namespace=
##bind script=script
##parameters= tree, flatList, current_path, current_obj, CSS_UL, CSS_LI, CSS_LI_Selected, themenu,
##title=
##

from Products.CMFCore.utils import getToolByName
from Products.CMFCore.permissions import View





#######################################################
# print_ul(print_tree)
#######################################################

def get_css(CSSList, depth):
    if not CSSList:
        return 'noclass'
    if len(CSSList) < depth:
        return CSSList[-1]
    else:
        return CSSList[depth-1]

def get_css_single(CSS):
    if not CSS:
        return 'noclass'
    else:
        return CSS


def print_ul(print_tree, selected_uid, depth):

    item_ul_css = get_css_single(CSS_UL)
    item_li_css = get_css(CSS_LI, depth)
    item_li_css_selected = get_css(CSS_LI_Selected, depth)
    
    menu_css_id = getCSSId()
    
    if menu_css_id:
        print '<div class="%s">' % menu_css_id        
    print '<ul class="%s">' % item_ul_css
    for i in print_tree:
        title = i['object'].Title
        ### Is it selected ?
        if selected_uid and i['reference_uid'] == selected_uid:
            print '<li class="%s">' % item_li_css_selected
        else:            
            print '<li class="%s">' % item_li_css
        ### Does it have a URL ?
        if i['reference_uid']:
            url = container.portal_url() + '/resolveUid/' + i['reference_uid']
            print '<a href="%s">%s</a>' % (url, title)
        else:
            print title
        
        print '</li>'
        if i.has_key('subtree') and i['subtree']:
            print print_ul(i['subtree'], selected_uid, depth + 1)
    print '</ul>'
    if menu_css_id:
        print '</div>'
    return printed                                                

def getCSSId():
    try:
        return themenu.getCSSId()
    except:
        pass
    return ''


#######################################################
# print_table(print_tree, selected_uid)
#######################################################

def print_tr(print_tree, selected_uid, depth):

    for i in print_tree:
        title = i['object'].Title

        print '</td></tr>'

        # Sub tree
        print print_tr(i['subtree'], selected_uid, depth + 1)
        
    return printed




#######################################################
# MAIN
#######################################################

#start = themenu.time()

result_getPrintTree = context.makeMenu_getPrintTree(tree, flatList, current_path, current_obj, themenu)
selected_uid = result_getPrintTree[0]
opened_list = result_getPrintTree[1]
print_tree = result_getPrintTree[2]

print print_ul(print_tree, selected_uid, 1)

#end = themenu.time()
#print end-start

return printed

==> smenu-0_6_8.tgz: SMenu/skins/SMenu/makeMenu_ul.py <==
## Script (Python) "makeMenu_ul"
##bind container=container
##bind context=context
##bind namespace=
##bind script=script
##parameters= tree, flatList, current_path, current_obj, CSS_UL, CSS_LI, CSS_LI_Selected, themenu,
##title=
##

from Products.CMFCore.utils import getToolByName
from Products.CMFCore.permissions import View

#######################################################
# print_ul(print_tree)
#######################################################

def get_css(CSSList, depth):
    if not CSSList:
        return 'noclass'
    if len(CSSList) < depth:
        return CSSList[-1]
    else:
        return CSSList[depth-1]


def get_css_single(CSS):
    if not CSS:
        return 'noclass'
    else:
        return CSS


def print_ul(print_tree, selected_uid, depth):

    item_ul_css = get_css(CSS_UL, depth)
    item_li_css = get_css(CSS_LI, depth)
    item_li_css_selected = get_css(CSS_LI_Selected, depth)
    
    print '<ul class="%s">' % item_ul_css
    for i in print_tree:
        title = i['object'].Title
        ### Is it selected ?
        if selected_uid and i['reference_uid'] == selected_uid:
            print '<li class="%s">' % item_li_css_selected
        else:
            print '<li class="%s">' % item_li_css
        ### Does it have a URL ?
        if i['uri']:
            url = i['uri']
            print '<a href="%s">%s</a>' % (url, title)
        elif i['reference_uid']:
            url = container.portal_url() + '/resolveUid/' + i['reference_uid']
            print '<a href="%s">%s</a>' % (url, title)
        else:
            print title        
        print '</li>'
        if i.has_key('subtree') and i['subtree']:
            print print_ul(i['subtree'], selected_uid, depth + 1)
    print '</ul>'
    return printed                                                

def getCSSId():
    try:
        return themenu.getCSSId()
    except:
        pass
    return ''


#######################################################
# MAIN
#######################################################

result_getPrintTree = context.makeMenu_getPrintTree(tree, flatList, current_path, current_obj, themenu)
selected_uid = result_getPrintTree[0]
opened_list = result_getPrintTree[1]
print_tree = result_getPrintTree[2]


menu_css_id = getCSSId()    
if menu_css_id:
    print '<div class="%s">' % menu_css_id        
print print_ul(print_tree, selected_uid, 1)
if menu_css_id:
    print '</div>'

return printed
